pub fn find_copper_partition<D: BlockDevice>(
sd: &D,
) -> Result<Option<(BlockIdx, BlockCount)>, D::Error>Expand description
Scan the GPT on the SD/eMMC card and return the block range of the Cu29 partition.
pub fn find_copper_partition<D: BlockDevice>(
sd: &D,
) -> Result<Option<(BlockIdx, BlockCount)>, D::Error>Scan the GPT on the SD/eMMC card and return the block range of the Cu29 partition.