pub struct EMMCSectionStorage<BD: BlockDevice> { /* private fields */ }Trait Implementations
Sourceimpl<BD: BlockDevice + Send> SectionStorage for EMMCSectionStorage<BD>
impl<BD: BlockDevice + Send> SectionStorage for EMMCSectionStorage<BD>
Sourcefn initialize<E: Encode>(&mut self, header: &E) -> Result<usize, EncodeError>
fn initialize<E: Encode>(&mut self, header: &E) -> Result<usize, EncodeError>
This rewinds the storage, serialize the header and jumps to the beginning of the user data storage.
Sourcefn post_update_header<E: Encode>(
&mut self,
header: &E,
) -> Result<usize, EncodeError>
fn post_update_header<E: Encode>( &mut self, header: &E, ) -> Result<usize, EncodeError>
This updates the header leaving the position to the end of the user data storage.
Sourceimpl<BD> UnifiedLogWrite<EMMCSectionStorage<BD>> for EMMCLogger<BD>
impl<BD> UnifiedLogWrite<EMMCSectionStorage<BD>> for EMMCLogger<BD>
Sourcefn add_section(
&mut self,
entry_type: UnifiedLogType,
requested_section_size: usize,
) -> CuResult<SectionHandle<EMMCSectionStorage<BD>>>
fn add_section( &mut self, entry_type: UnifiedLogType, requested_section_size: usize, ) -> CuResult<SectionHandle<EMMCSectionStorage<BD>>>
A section is a contiguous chunk of memory that can be used to write data.
It can store various types of data as specified by the entry_type.
The requested_section_size is the size of the section to allocate.
It returns a handle to the section that can be used to write data until
it is flushed with flush_section, it is then considered unmutable.
Sourcefn flush_section(&mut self, section: &mut SectionHandle<EMMCSectionStorage<BD>>)
fn flush_section(&mut self, section: &mut SectionHandle<EMMCSectionStorage<BD>>)
Flush the given section to the underlying storage.
Sourcefn status(&self) -> UnifiedLogStatus
fn status(&self) -> UnifiedLogStatus
Returns the current status of the unified logger.