ForceSyncSend

Struct ForceSyncSend 

pub struct ForceSyncSend<T>(/* private fields */);
Wrapper to share a block device behind Arc without adding locking.

Safety

This type provides unsynchronized interior mutability. Only use it when all access is externally serialized (single-threaded execution or a higher-level mutex).

Implementations

Source

impl<T> ForceSyncSend<T>

pub const fn new(inner: T) -> Self