pub struct ForceSyncSend<T>(/* private fields */);Expand description
Wrapper to share a block device behind Arc without adding locking.
Safety
This type provides unsynchronized interior mutability. Only use it when all access is externally serialized (single-threaded execution or a higher-level mutex).
Implementations
Sourceimpl<T> ForceSyncSend<T>
impl<T> ForceSyncSend<T>